@@ -3,7 +3,7 @@ use ash::vk;
 use crate::GuardedResource;
 
 /// Extension trait adding guarded methods to [`ash::EntryCustom`]
-pub trait EntryGuardedMethods {
+pub trait EntryExt {
     /// Same as [ash::EntryCustom::create_instance] but returns guarded instance
     #[allow(clippy::missing_safety_doc)]
     unsafe fn create_guarded_instance<'a>(
@@ -13,7 +13,7 @@ pub trait EntryGuardedMethods {
     ) -> Result<GuardedResource<'a, ash::Instance, &'static ()>, ash::InstanceError>;
 }
 
-impl<L> EntryGuardedMethods for ash::EntryCustom<L> {
+impl<L> EntryExt for ash::EntryCustom<L> {
     unsafe fn create_guarded_instance<'a>(
         &self,
         create_info: &vk::InstanceCreateInfo,
