@@ -1,10 +1,11 @@
-#![doc(html_root_url = "https://docs.rs/ashpan/0.1.0")]
+#![doc(html_root_url = "https://docs.rs/ashpan/0.3.0")]
 //! This crate provides RAII helpers for [`ash`]. In particular:
 //!
-//! * [`Guarded`]/[`GuardedResource`] is essentially a [`ScopeGuard`](scopeguard::ScopeGuard) that
-//!   selects an appropriate destructor automatically.
-//! * [`DeviceGuardedMethods`] (along with [`EntryGuardedMethods`] and [`InstanceGuardedMethods`])
-//!   provide convenience methods to create resources and wrap them in [`GuardedResource`]s.
+//! * [`Guarded`]/[`GuardedResource`] is essentially a
+//!   [`ScopeGuard`](https://docs.rs/scopeguard/1.1.0/scopeguard/struct.ScopeGuard.html)
+//!   that selects an appropriate destructor automatically.
+//! * [`DeviceExt`] (along with [`EntryExt`] and [`InstanceExt`]) provide convenience methods to
+//!   create resources and wrap them in [`GuardedResource`]s.
 //! * [`Destroyable`] allows you to extend the behavior of [`GuardedResource`].
 //!
 //! # Introduction
@@ -47,8 +48,8 @@
 //! # }
 //! ```
 //!
-//! It's straightforward to solve this with [`scopeguard`], but it tends to be a bit verbose and
-//! repetitive:
+//! It's straightforward to solve this with [`scopeguard`](https://docs.rs/scopeguard/), but it
+//! tends to be a bit verbose and repetitive:
 //!
 //! ```
 //! # use ash::{prelude::VkResult, vk};
@@ -96,13 +97,14 @@
 //! # }
 //! ```
 //!
-//! [`ashpan`](crate) reduces the friction of using [`scopeguard`] with [`ash`] by automatically
-//! selecting the destructor, passing the same `allocation_callbacks` to the destructor that were
-//! used for resource creation and making guarded resources convenient to extract:
+//! [`ashpan`](crate) reduces the friction of using [`scopeguard`](https://docs.rs/scopeguard/)
+//! with [`ash`] by automatically selecting the destructor, passing the same
+//! `allocation_callbacks` to the destructor that were used for resource creation and making
+//! guarded resources convenient to extract:
 //!
 //! ```
 //! # use ash::{prelude::VkResult, vk};
-//! use ashpan::{DeviceGuardedMethods, Guarded};
+//! use ashpan::{DeviceExt, Guarded};
 //! #
 //! # struct Resources {
 //! #     render_pass: vk::RenderPass,
@@ -145,7 +147,7 @@
 //!
 //! ```
 //! # use ash::{prelude::VkResult, vk};
-//! use ashpan::{Destroyable, DeviceGuardedMethods, Guarded};
+//! use ashpan::{Destroyable, DeviceExt, Guarded};
 //! #
 //! # struct Resources {
 //! #     render_pass: vk::RenderPass,
@@ -181,17 +183,14 @@ mod guarded;
 mod instance;
 
 pub use destroy::Destroyable;
-pub use device::DeviceGuardedMethods;
-pub use entry::EntryGuardedMethods;
+pub use device::DeviceExt;
+pub use entry::EntryExt;
 pub use guarded::{Guarded, GuardedResource};
-pub use instance::InstanceGuardedMethods;
+pub use instance::InstanceExt;
 
 #[cfg(test)]
 mod tests {
-    use crate::{
-        Destroyable, DeviceGuardedMethods, EntryGuardedMethods, GuardedResource,
-        InstanceGuardedMethods,
-    };
+    use crate::{Destroyable, DeviceExt, EntryExt, GuardedResource, InstanceExt};
     use ash::vk;
 
     #[derive(Debug, PartialEq)]
